////////////////////////////////////////////////////////////////////////////////
//QALab is released under the GNU General Public License.
//
//QALab: Collects QA Statistics from your build over time.
//2005+, ObjectLab Ltd
//
//This library is free software; you can redistribute it and/or
//modify it under the terms of the GNU General Public
//License as published by the Free Software Foundation; either
//version 2.1 of the License, or (at your option) any later version.
//
//This library is distributed in the hope that it will be useful,
//but WITHOUT ANY WARRANTY; without even the implied warranty of
//MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//General Public License for more details.
//
//You should have received a copy of the GNU General Public
//License along with this library; if not, write to the Free Software
//Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
////////////////////////////////////////////////////////////////////////////////
package net.objectlab.qalab.exporter;

import net.objectlab.qalab.interfaces.QALabExporter;
import net.objectlab.qalab.util.ConsoleLogger;
import net.objectlab.qalab.util.TaskLogger;

import java.io.IOException;

import java.util.Properties;

/**
 * This is a basic exporter for debugging (it simply shows the exports on
 * ConsoleLogger.
 * @author Benoit Xhenseval
 * @version $Revision$
 */
public class ConsoleExporter implements QALabExporter {
    /** given implementation for the logger. **/
    private TaskLogger taskLogger = new ConsoleLogger();

    /** if true, no debug information is logged. **/
    private boolean quiet = true;

    /**
     * For instance for the XML Exporter.
     * <ul>
     * <li>qalab.outputfile = the output file name and path.</li>
     * <li>qalab.classname = alternatively, the XML could be a
     * resource for this class</li>
     * <li>qalab.resourcename = the resource name for
     * the qalab.classname given</li>
     * </ul>
     * @param properties the properties.
     * @see net.objectlab.qalab.interfaces.
     * QALabExporter#configure(java.util.Properties)
     */
    public final void configure(final Properties properties) {
        getTaskLogger().log("Configure:" + properties);
    }

    /**
     * Add summary details for this merger of statistics for this type.
     * @param violationCount total number of violations for this type
     * @param fileCount total number of files affected by this type.
     * @see net.objectlab.qalab.interfaces.QALabExporter#addSummary(
     * java.util.Date, int, int, java.lang.String)
     */
    public final void addSummary(final int violationCount,
            final int fileCount) {
        getTaskLogger().log("AddSummary:"
            + " violations:" + violationCount + " files:" + fileCount);
    }

    /**
     * Add a result entry for a given file name and type.
     * @param violationCount total number of violations for this type and file.
     * @param fileName file name
     * @see net.objectlab.qalab.interfaces.QALabExporter#addFileResult(
     * java.util.Date, int, java.lang.String, java.lang.String)
     */
    public final void addFileResult(final int violationCount,
            final String fileName) {
        getTaskLogger().log("AddFileResult:"
            + " violations:" + violationCount + " file:" + fileName);
    }

    /**
     * Save the stats (called when the parsing of input statistics is
     * completed).
     * @see net.objectlab.qalab.interfaces.QALabExporter#save()
     */
    public final void save() throws IOException {
        getTaskLogger().log("save");
    }

    /**
     * @return logger to use if not quiet.
     */
    protected final TaskLogger getTaskLogger() {
        return taskLogger;
    }

    /**
     * set the task logger, ie mechanism to log issues & debug info.
     * @param task the logger to use
     */
    public final void setTaskLogger(final TaskLogger task) {
        taskLogger = task;
    }

    /**
     * @return true means that no debug info is logged.
     */
    public final boolean isQuiet() {
        return quiet;
    }

    /**
     * @param noLog true if no log required.
     */
    public final void setQuiet(final boolean noLog) {
        this.quiet = noLog;
    }
}
