////////////////////////////////////////////////////////////////////////////////
//QALab is released under the GNU General Public License.
//
//QALab: Collects QA Statistics from your build over time.
//2005+, ObjectLab Ltd
//
//This library is free software; you can redistribute it and/or
//modify it under the terms of the GNU General Public
//License as published by the Free Software Foundation; either
//version 2.1 of the License, or (at your option) any later version.
//
//This library is distributed in the hope that it will be useful,
//but WITHOUT ANY WARRANTY; without even the implied warranty of
//MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//General Public License for more details.
//
//You should have received a copy of the GNU General Public
//License along with this library; if not, write to the Free Software
//Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
////////////////////////////////////////////////////////////////////////////////
package net.objectlab.qalab.interfaces;

import net.objectlab.qalab.util.TaskLogger;

import java.io.IOException;

import java.util.Properties;

/**
 * This is the interface for exporting the statistics from the input
 * checkstyle, pmd, findbugs or simian; feel free to create your own
 * to say a database or your specific XML.
 * @author Benoit Xhenseval
 * @version $Revision$
 */
public interface QALabExporter {
    /**
     * Configure the exporter.
     * For instance for the XML Exporter.
     * <ul>
     * <li>qalab.outputfile = the output file name and path.</li>
     * <li>qalab.classname = alternatively, the XML could be a
     * resource for this class</li>
     * <li>qalab.resourcename = the resource name
     * for the qalab.classname given</li>
     * </ul>
     * @param properties the properties used to confirgure the exporter.
     */
    void configure(final Properties properties);

    /**
     * Add summary details for this merger of statistics for this type.
     * @param violationCount total number of violations for this type
     * @param fileCount total number of files affected by this type.
     */
    void addSummary(final int violationCount, final int fileCount);

    /**
     * Add a result entry for a given file name and type.
     * @param violationCount total number of violations for this type and file.
     * @param fileName file name
     * simian, pmd)
     */
    void addFileResult(final int violationCount,
        final String fileName);

    /**
     * Save the results wherever required (depending on the Exporter).
     * @throws IOException any IO issue.
     */
    void save() throws IOException;

    /**
     * set the task logger, ie mechanism to log issues & debug info.
     * @param task the logger to use
     */
    void setTaskLogger(TaskLogger task);

    /**
     * if quiet is true, the merger should limit its log output.
     * @param quiet true to minimise logging.
     */
    void setQuiet(boolean quiet);
}
