////////////////////////////////////////////////////////////////////////////////
//QALab is released under the GNU General Public License.
//
//QALab: Collects QA Statistics from your build over time.
//2005+, ObjectLab Ltd
//
//This library is free software; you can redistribute it and/or
//modify it under the terms of the GNU General Public
//License as published by the Free Software Foundation; either
//version 2.1 of the License, or (at your option) any later version.
//
//This library is distributed in the hope that it will be useful,
//but WITHOUT ANY WARRANTY; without even the implied warranty of
//MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//General Public License for more details.
//
//You should have received a copy of the GNU General Public
//License along with this library; if not, write to the Free Software
//Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
////////////////////////////////////////////////////////////////////////////////
package net.objectlab.qalab.parser;

import net.objectlab.qalab.util.QALabTags;

import java.util.Date;

/**
 * A class to store each result which are stored as part of the FileStat. This
 * class holds the following data; date, no. of errors and the type of reporting
 * 
 * @author Paramjit Rehinsi
 * @version $Revision: 1.9 $
 */
public class SingleStat {
    /**
     * Date and time of the statistics.
     */
    private Date datetime = null;

    /**
     * stat value detected.
     */
    private int statvalue;

    /**
     * type of error detected.
     */
    private String type;

    /**
     * @param date
     *            the date and time of detection of the errors.
     */
    public final void setDate(final Date date) {
        this.datetime = new Date(date.getTime());
    }

    /**
     * @return the date and time of detection of the errors.
     */
    public final Date getDate() {
        if (datetime != null) {
            return new Date(datetime.getTime());
        } else {
            return null;
        }
    }

    /**
     * @param errors
     *            the error count detected.
     */
    public final void setStatValue(final int errors) {
        this.statvalue = errors;
    }

    /**
     * @return the error count.
     */
    public final int getStatValue() {
        return this.statvalue;
    }

    /**
     * @param statisticsType
     *            checkstyle|findbugs|pmd|simian
     */
    public final void setType(final String statisticsType) {
        this.type = statisticsType;
    }

    /**
     * @return the statistic type
     */
    public final String getType() {
        return this.type;
    }

    /**
     * @return a text representation
     */
    public final String toString() {
        StringBuffer buf = new StringBuffer();

        buf.append(type).append(" - ");
        buf.append(QALabTags.DEFAULT_DATETIME_FORMAT.format(datetime));
        buf.append(" - V:").append(statvalue);

        return buf.toString();
    }
}
