////////////////////////////////////////////////////////////////////////////////
//QALab is released under the GNU General Public License.
//
//QALab: Collects QA Statistics from your build over time.
//2005+, ObjectLab Ltd
//
//This library is free software; you can redistribute it and/or
//modify it under the terms of the GNU General Public
//License as published by the Free Software Foundation; either
//version 2.1 of the License, or (at your option) any later version.
//
//This library is distributed in the hope that it will be useful,
//but WITHOUT ANY WARRANTY; without even the implied warranty of
//MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//General Public License for more details.
//
//You should have received a copy of the GNU General Public
//License along with this library; if not, write to the Free Software
//Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
////////////////////////////////////////////////////////////////////////////////
package net.objectlab.qalab.parser;

import org.xml.sax.InputSource;

import net.objectlab.qalab.interfaces.QALabExporter;
import net.objectlab.qalab.util.TaskLogger;

/**
 * Interface defining the statistics mergers.  There will be implementations
 * for Checkstyle, PMD, FindBugs and Simian.
 *
 * Created by IntelliJ IDEA. User: xhensevalb Date: 17-Feb-2004 Time: 10:27:11
 * @author Benoit Xhenseval
 * @version $Revision: 1.12 $
 */
public interface StatMerger {
    // ~ Methods
    // ------------------------------------------------------------------------

    /**
     * if quiet is true, the merger should limit its log output.
     * @param quiet true to minimise logging.
     */
    void setQuiet(boolean quiet);

    /**
     * set the task logger, ie mechanism to log issues & debug info.
     * @param task the logger to use
     */
    void setTaskLogger(TaskLogger task);

    /**
     * Stipulates the source directory for the code.
     * @param srcDir the source directory.
     */
    void setSrcDir(String srcDir);

    /**
     * @return the total number of 'violations' detected.
     */
    int getTotalStatistics();

    /**
     * @return the number of files found.
     */
    int getFileCount();

    /**
     * merge the stats from node to the combined stats document.
     * @param source the XML containing the new statistics.
     * @param exporter the exporter to use for the compiled stats.
     */
    void mergeStats(InputSource source, QALabExporter exporter);

    /**
     * @return the statistics type handled by this merger.
     */
    String getType();

    /**
     * set the timestamp (optional) for the merged stats.
     * @param timestamp the time stamp in format YYYY-MM-dd HH:mm:ss
     * @param timeStampAsDate The timeStampAsDateOnly to set.
     */
    void setMergerTimeStamp(final String timestamp,
            final boolean timeStampAsDate);

    /**
     * This may have been changed to "now".
     * @return timestamp the time stamp in format YYYY-MM-dd HH:mm:ss
     */
    String getMergerTimeStamp();
}
