////////////////////////////////////////////////////////////////////////////////
//QALab is released under the GNU General Public License.
//
//QALab: Collects QA Statistics from your build over time.
//2005+, ObjectLab Ltd
//
//This library is free software; you can redistribute it and/or
//modify it under the terms of the GNU General Public
//License as published by the Free Software Foundation; either
//version 2.1 of the License, or (at your option) any later version.
//
//This library is distributed in the hope that it will be useful,
//but WITHOUT ANY WARRANTY; without even the implied warranty of
//MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//General Public License for more details.
//
//You should have received a copy of the GNU General Public
//License along with this library; if not, write to the Free Software
//Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
////////////////////////////////////////////////////////////////////////////////
package net.objectlab.qalab.util;

import java.util.ArrayList;
import java.util.Collections;
import java.util.Iterator;
import java.util.List;
import java.util.StringTokenizer;

import org.w3c.dom.NamedNodeMap;
import org.w3c.dom.Node;
import org.xml.sax.Attributes;

/**
 * Utility class for list generation and parsing.
 * 
 * @author Benoit Xhenseval
 * @version $Revision: 1.11 $
 */
public final class Util {
    /**
     * default constructor.
     */
    private Util() {
    }

    /**
     * helper method to convert a 'delimiter' separated string to a list.
     * 
     * @param str
     *            the 'delimiter' separated string
     * @param delimiter
     *            typically a ','
     * @return a list
     */
    public static List listify(final String str, final String delimiter) {
        if (str == null) {
            return Collections.EMPTY_LIST;
        }

        final StringTokenizer tok = new StringTokenizer(str, delimiter);
        final List list = new ArrayList();

        while (tok.hasMoreElements()) {
            list.add(tok.nextToken().trim());
        }

        return list;
    }

    /**
     * convert a list to a comma separated string.
     * 
     * @param list
     *            list to "print"
     * @return a String comma separated.
     */
    public static String listToCSVString(final List list) {
        StringBuffer buf = new StringBuffer();

        if (list != null) {
            boolean first = true;

            for (Iterator it = list.iterator(); it.hasNext(); first = false) {
                if (!first) {
                    buf.append(",");
                }

                buf.append((it.next()).toString());
            }
        }

        return buf.toString();
    }

    /**
     * Gets the attribute value.
     * 
     * @param attrs
     *            SAX XML attributes.
     * @param attrName
     *            attribute name
     * @param quiet
     *            if true, no logging
     * @param logger
     *            the logger to use
     * @return String the attribute value
     */
    public static String getAttributeValue(final Attributes attrs, // NOPMD
            final String attrName, final boolean quiet, // NOPMD
            final TaskLogger logger) { // NOPMD
        if (attrs != null) {
            final String value = attrs.getValue(attrName);
            // if (!quiet) {
            // logger.log("Attribute:" + attrName + " value="
            // + value);
            // }
            return value;
        }

        return null;
    }

    /**
     * Gets the attribute value.
     * 
     * @param attrs
     *            DOM XML attributes.
     * @param attrName
     *            attribute name
     * @param quiet
     *            if true, no logging
     * @param logger
     *            the logger to use
     * @return String the attribute value
     */
    public static String getAttributeValue(final NamedNodeMap attrs, // NOPMD
            final String attrName, final boolean quiet, // NOPMD
            final TaskLogger logger) { // NOPMD
        String value = null;
        if (attrs != null) {
            final Node nodeValue = attrs.getNamedItem(attrName);
            if (nodeValue != null) {
                value = nodeValue.getNodeValue();
            }
            // if (!quiet) {
            // logger.log("Attribute DOM:" + attrName + " value=" + value);
            // }
        }

        return value;
    }
}
